import { Vue } from "vue-property-decorator";
import { ElLoadingComponent } from "element-ui/types/loading";
import { ActionPopedomDTO, ActionPopedomService, AppAccountDTO, DomainPopedomDTO, DomainPopedomService, HttpClient, MenuPopedomService, RoleDTO, RoleService, RoleTypeEnum } from "@ytd/fe-core";
import { CreateElement, VNode } from "vue";
import { AugmentMenuPopedomDTO, DomainTreeNode, IYtdPopedomPageSaveDomainPopedomDialogProp } from "../../../vms/index";
export default class YtdPopedomPage extends Vue {
    httpClient: HttpClient;
    /**
     * 角色ID
     */
    roleId: string;
    /**
     * 领域树节点
     */
    domainNodes: DomainTreeNode[];
    /**
     * 要启用的权限列表，默认全部启用；
     */
    tabPanes: Array<"menu" | "action" | "domain">;
    RoleTypeEnum: typeof RoleTypeEnum;
    /**
     * 角色服务
     * @type {RoleService}
     */
    roleService: RoleService;
    /**
     * 菜单权限服务
     * @type {MenuPopedomService}
     */
    menuPopedomService: MenuPopedomService;
    /**
     * 动作权限服务
     * @type {ActionPopedomService}
     */
    actionPopedomService: ActionPopedomService;
    /**
     * 领域权限服务
     * @type {DomainPopedomService}
     */
    domainPopedomService: DomainPopedomService;
    /**
     * 角色列表
     * @type {RoleDTO[]}
     */
    roles: RoleDTO[];
    /**
     * 当前选中角色
     * @type {RoleDTO}
     */
    role: RoleDTO;
    /**
     * 应用账户
     * @type {AppAccountDTO}
     */
    appAccount: AppAccountDTO;
    activeTab: string;
    /**
     * 菜单权限列表
     */
    menuPopedoms: AugmentMenuPopedomDTO[];
    /**
     * 动作权限列表
     */
    actionPopedoms: ActionPopedomDTO[];
    /**
     * 领域权限列表
     */
    domainPopedoms: DomainPopedomDTO[];
    actionPopedomsLoading: boolean;
    actionPopedomsLoadingVm: ElLoadingComponent | null;
    domainPopedomsLoading: boolean;
    domainPopedomsLoadingVm: ElLoadingComponent | null;
    /**
     * '保存领域权限'弹窗属性
     */
    ytdPopedomPageSaveDomainPopedomDialogProp: IYtdPopedomPageSaveDomainPopedomDialogProp;
    onDomainNodesChanged(domainNodes: DomainTreeNode[]): void;
    onDomainPopedomsLoadingChanged(loading: boolean): void;
    onActionPopedomsLoadingChanged(loading: boolean): void;
    mounted(): void;
    /**
     * 选中角色
     */
    handleRoleChange(role: RoleDTO): void;
    /**
     * 勾选菜单权限'授权'
     */
    handleMenuPopedomAllowChange(command: string): void;
    /**
     * 勾选动作权限'授权'
     */
    handleActionPopedomAllowChange(command: string): void;
    /**
     * 渲染菜单权限树节点
     * @param {CreateElement} h
     * @param {*} _self
     * @param {*} node
     * @param {MenuPopedomDTO} data
     * @returns {string}
     */
    renderMenuPopedomTreeNode(h: CreateElement, { _self, node, data: menuPopedom }: {
        _self: any;
        node: any;
        data: AugmentMenuPopedomDTO;
    }): VNode;
    /**
     * 加载领域权限
     */
    loadDomainPopedom(): void;
    /**
     * 打开'保存领域权限'弹窗
     * @parem {DomainPopedomDTO} domainPopedom
     */
    openDomainSaveDialog(domainPopedom?: DomainPopedomDTO): void;
    /**
     * 删除领域权限
     * @param {DomainPopedomDTO} domainPopedom
     */
    deleteDomainPopedom(domainPopedom: DomainPopedomDTO): void;
    handleYtdPopedomPageSaveDomainPopedomDialogClose(): void;
    /**
     * 更新动作权限
     * @param {ActionPopedomDTO} actionPopedom
     */
    updateActionPopedom(actionPopedom: ActionPopedomDTO): void;
}
