import { Q } from "../../lib/qunee";
import { YtdQuneeWindow } from "./YtdQuneeWindow";
import { Vue } from "vue-property-decorator";
import { IYtdContextMenu } from "../../vms";
import { YtdQuneeTooltip } from "./YtdQuneeTooltip";
import { YtdContextMenu } from "../ytd-context-menu/YtdContextMenu";
import { CreateElement } from "vue";
/**
 * 拓扑图
 */
export declare class YtdQunee extends Vue {
    /** 图元右键菜单 */
    menus: Array<IYtdContextMenu>;
    /**
     * 顶部工具栏；
     * false: 隐藏工具栏；
     * 否则为要显示的工具栏按钮的名称列表；
     * @example
     *   :toolbar="false"
     *   :toolbar="['view', 'fullscreen']"
     */
    toolbar: boolean | Array<string>;
    /**
     * 附加的默认右键菜单；
     * 右键点击空白处，默认会弹出一组菜单（导出图片，重新加载，等等），通过此参数可以在默认菜单前面添加额外的菜单；
     */
    prependDefaultMenus: Array<IYtdContextMenu>;
    /** 是否可以编辑 */
    isEditable: boolean;
    /** 是否启用网格背景 */
    gridBackground: boolean;
    /**
     * 查找节点时要进行关键字匹配的属性路径
     * @example
     *   :search-paths="['x', 'x.y']"
     */
    searchPaths: Array<string>;
    /** 默认选中的图元ID */
    selectId: string | number;
    /** 导出的图片的标题 */
    exportPictureTitle: string;
    /** 是否可以拖动底部边缘调整组件高度 */
    resizable: boolean;
    /** 是否启用'预览'面板 */
    enableWindowOverview: boolean;
    /** 提示信息：延迟 */
    tooltipDelay: number;
    /** 提示信息：距离拓扑图边框的距离（单位：px） */
    tooltipOffset: number;
    /** 加载中的提示文本 */
    loadingText: string;
    $refs: {
        ytdQuneeTooltipRef: YtdQuneeTooltip;
        ytdQuneeContextMenuRef: YtdContextMenu;
        ytdQuneeWindowOverviewRef: YtdQuneeWindow;
    };
    NAV_MENU_COLLAPSED: boolean;
    /** 酷利元素ID */
    private eid;
    private graph;
    private loading;
    private isFullscreen;
    /** 复制的图元 */
    private copiedElements;
    private filter;
    private searchInfo;
    private leftWindows;
    private rightWindows;
    private bottomWindows;
    private visibleLeftWindows;
    private visibleRightWindows;
    private visibleBottomWindows;
    private ytdQuneeWindowOverviewProp;
    private ytdQuneeTooltipProp;
    /**
     * 默认菜单（右键点击空白处）
     */
    readonly defaultMenus: Array<IYtdContextMenu>;
    readonly reverseDefaultMenus: Array<IYtdContextMenu>;
    /**
     * 右键菜单列表
     */
    readonly ytdContextMenuMenus: Array<IYtdContextMenu>;
    onOvervieweWindowVisibleChanged(visible: boolean): void;
    onVisibleBottomWindowsChanged(visibleBottomWindows: Array<YtdQuneeWindow>): void;
    onSelectIdChanged(selectId: string | number): void;
    onIsEditableChanged(): void;
    onMenuCollapsedChanged(): Promise<void>;
    activated(): void;
    mounted(): void;
    beforeDestroy(): void;
    /**
     * 加载
     */
    load(): void;
    /**
     * 显示加载提示
     */
    showLoading(): Promise<void>;
    /**
     * 隐藏加载提示
     */
    hideLoading(): Promise<void>;
    /**
     * 隐藏鼠标提示信息
     */
    hideTooltip(): void;
    /**
     * 关闭所有面板
     */
    closeAllWindows(): void;
    /**
     * 获取 graph 对象
     */
    getGraph(): Q.Graph | null;
    private init;
    /**
     * 更新视图
     */
    private updateViewport;
    /**
     * DOM 事件绑定
     */
    private initDomEvent;
    /**
     * window 的 resize 事件回调
     */
    private handleWindowResize;
    /**
     * fullscreenchange 事件回调
     */
    private handleFullscreenChange;
    /**
     * 切换全屏
     */
    private toggleFullScreen;
    /**
     * 原始比例
     * @param graph
     */
    private zoomToOriginal;
    /**
     * 导出图片
     * @param graph
     */
    private exportImage;
    /**
     * 重新加载
     * @param graph
     */
    private reload;
    /**
     * 初始化'预览'面板
     */
    private initOverviewWindow;
    /**
     * 初始化面板
     */
    private initWindows;
    /**
     * 切换左侧面板
     * @param visible 是否显示
     * @param leftWindow 面板
     */
    private handleToggleLeftWindow;
    /**
     * 切换右侧面板
     * @param visible 是否显示
     * @param rightWindow 面板
     */
    private handleToggleRightWindow;
    /**
     * 切换底部面板
     * @param visible 是否显示
     * @param bottomWindow 面板
     */
    private handleToggleBottomWindow;
    /**
     * 选中图元
     * @param id 图元ID
     */
    private selectElement;
    /**
     * 查找图元
     * @param key 关键字
     * @param showEmptyMessasge 是否显示'搜索结果为空'的提示消息
     */
    private searchElement;
    /**
     * 复制图元
     */
    private copyElements;
    /**
     * 粘贴图元
     * @param dx 横坐标偏移
     * @param dy 纵坐标偏移
     */
    private pasteElements;
    /**
     * 点击右键菜单
     * @param menu 右键菜单
     */
    private handleContextMenuClick;
    render(h: CreateElement): JSX.Element;
}
