import { Vue } from "vue-property-decorator";
import { AppAccountRoleService, AppAccountService, HttpClient, RoleService, WorkflowDTO, WorkflowService } from "@ytd/fe-core";
import { YtdQunee } from "../qunee/YtdQunee";
import { Q } from "../../lib/qunee";
import { IYtdContextMenu, IYtdWorkflowSaveEdgeDialogProp, IYtdWorkflowSaveNodeDialogProp } from "../../vms/index";
import { CreateElement } from "vue";
/**
 * 流程定义
 */
export declare class YtdWorkflow extends Vue {
    httpClient: HttpClient;
    /** 流程 */
    workflow: WorkflowDTO;
    /** 流程轨迹 */
    workflowTrack: WorkflowDTO.TrackDTO;
    workflowService: WorkflowService;
    roleService: RoleService;
    appAccountService: AppAccountService;
    appAccountRoleService: AppAccountRoleService;
    graph: Q.Graph | null;
    ytdQuneeProp: {
        id: string;
        menus: Array<IYtdContextMenu>;
    };
    ytdWorkflowSaveNodeDialogProp: IYtdWorkflowSaveNodeDialogProp;
    ytdWorkflowSaveEdgeDialogProp: IYtdWorkflowSaveEdgeDialogProp;
    /** 是否正在添加节点 */
    isNodeAdding: boolean;
    /** 是否正在添加连线 */
    isEdgeAdding: boolean;
    /** 提示消息 */
    messageTitle: string;
    /**
     * 是否显示提示消息
     * 点击'添加任务'和'添加连线'菜单后，进入编辑模式，显示提示消息；
     * 此属性用于判断当前模式（正常，编辑）
     */
    readonly isMessageVisible: boolean;
    /**
     * 流程是否尚未发布
     * 发布的流程不能编辑，不能删除，不能移动任务节点位置
     */
    readonly isDraft: boolean;
    /**
     * 工具栏按钮
     */
    readonly prependToolbarButtons: {
        name: string;
        code: string;
        icon: string;
        handler(graph: Q.Graph): void;
    }[];
    onWorkflowChanged(workflow: WorkflowDTO): void;
    /**
     * @param graph
     */
    handleYtdQuneeReady(graph: Q.Graph): void;
    /**
     * 更新任务节点坐标
     * @param node
     */
    upateNodeCoordiate(node: WorkflowDTO.NodeDTO): void;
    /**
     * 元素属性改变
     * @param e
     */
    handleYtdQuneeDataPropertyChange(e: Q.Event): void;
    /**
     *
     * @param self
     * @param graph
     */
    handleLoad(self: YtdQunee, graph: Q.Graph): void;
    /**
     *
     * @param self
     * @param graph
     */
    handleReload(self: YtdQunee, graph: Q.Graph): void;
    /**
     * 右键菜单
     * @param self
     * @param graph
     * @param element
     * @param elementUI
     * @param ui
     */
    handleContextMenu(self: YtdQunee, graph: Q.Graph, element: Q.Element, elementUI: Q.ElementUI, ui: Q.BaseUI): void;
    /**
     *
     * @param self
     * @param graph
     * @param element
     * @param elementUI
     * @param ui
     * @param e
     */
    handleClick(self: YtdQunee, graph: Q.Graph, element: Q.Element, elementUI: Q.ElementUI, ui: Q.BaseUI, e: MouseEvent): void;
    /**
     * 加载任务
     * @param node
     * @param elementMap
     */
    loadNode(node: WorkflowDTO.NodeDTO, elementMap: Map<string, Q.Element>): void;
    /**
     * 加载连线
     * @param edge
     * @param elementMap
     */
    loadEdge(edge: WorkflowDTO.EdgeDTO, elementMap: Map<string, Q.Element>): void;
    /**
     * 添加任务弹窗关闭
     */
    handleYtdWorkflowSaveNodeDialogClose(isCanceled: boolean): void;
    /**
     * 添加连线弹窗关闭
     */
    handleYtdWorkflowSaveEdgeDialogClose(isCanceled: boolean): void;
    /**
     * 添加连线监听器
     * @param e
     */
    addEdgeListener(e: Q.ListEvent): void;
    render(h: CreateElement): JSX.Element;
    $refs: {
        ytdQuneeRef: YtdQunee;
    };
}
